@@ -13,6 +13,15 @@ m1 <- gge(yield~gen*env, dat1, scale=FALSE)
 biplot(m1, title="yan.winterwheat - GGE biplot",
        flip=c(1,0), origin=0, hull=TRUE)
 
+## ---------------------------------------------------------------------------------------
+m2 <- gge(yield~gen*env, dat1, scale=TRUE)
+biplot(m2, title="yan.winterwheat - GGE biplot",
+       flip=c(1,1), origin=0)
+
+## ---------------------------------------------------------------------------------------
+biplot(m2, title="yan.winterwheat - GGE biplot - PC 2 & 3",
+       comps=c(2,3), flip=c(1,1), origin=0)
+
 ## ----mosaic-----------------------------------------------------------------------------
 plot(m1, title="yan.winterwheat")
 
@@ -29,6 +38,10 @@ dat2$eg <- ifelse(is.element(dat2$loc,
 
 library(gge)
 # Specify env.group as column in data frame
-m2 <- gge(yield~gen*loc, dat2, env.group=eg, scale=FALSE)
-biplot(m2, title="crossa.wheat - GGB biplot")
+m3 <- gge(yield~gen*loc, dat2, env.group=eg, scale=FALSE)
+biplot(m3, title="crossa.wheat - GGB biplot")
+
+
+## ----session----------------------------------------------------------------------------
+sessionInfo()
 
